[SCM] Multi-format 1D/2D barcode image processing library branch, upstream, updated. 24d4480bc48cf9eabf7b2bd2f528248b0e458809

srowen srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57
Wed Aug 4 01:32:05 UTC 2010


The following commit has been merged in the upstream branch:
commit 6cd49fe778ca42ddbf0ae497dc207b0e08f0b4b8
Author: srowen <srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57>
Date:   Tue Jun 15 18:43:10 2010 +0000

    Back to white backgrounds, somewhat smaller text in the result screen, shorter Toast popup and doesn't interfere with help screen
    
    git-svn-id: http://zxing.googlecode.com/svn/trunk@1429 59b500cc-1b3d-0410-9834-0bbf25fbcc57

diff --git a/android/assets/html/style.css b/android/assets/html/style.css
index 4a0e7a5..93f769a 100644
--- a/android/assets/html/style.css
+++ b/android/assets/html/style.css
@@ -1,12 +1,9 @@
 body {
-  background-color: black;
-  color: white;
+  background-color: white;
+  color: black;
   font-family: Arial sans-serif;
   font-size: 14pt;
 }
-a:link, a:visited, a:active {
-  color: white;
-}
 ul.touchable li {
   padding-top:8px;
   padding-bottom:8px;
diff --git a/android/res/values/colors.xml b/android/res/values/colors.xml
index 91279b6..1872d5b 100755
--- a/android/res/values/colors.xml
+++ b/android/res/values/colors.xml
@@ -31,8 +31,8 @@
   <color name="sbc_layout_view">#ffffffff</color>
   <color name="sbc_page_number_text">#ff000000</color>
   <color name="sbc_snippet_text">#ff4b4b4b</color>
-  <color name="share_text">#ffffffff</color>
-  <color name="share_view">#ff000000</color>
+  <color name="share_text">#ff000000</color>
+  <color name="share_view">#ffffffff</color>
   <color name="status_view">#50000000</color>
   <color name="status_text">#ffffffff</color>
   <color name="transparent">#00000000</color>
diff --git a/android/src/com/google/zxing/client/android/CaptureActivity.java b/android/src/com/google/zxing/client/android/CaptureActivity.java
index 2154a88..61fd4bd 100755
--- a/android/src/com/google/zxing/client/android/CaptureActivity.java
+++ b/android/src/com/google/zxing/client/android/CaptureActivity.java
@@ -150,6 +150,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
   private String characterSet;
   private String versionName;
   private HistoryManager historyManager;
+  private boolean firstLaunch;
 
   private final OnCompletionListener beepListener = new BeepListener();
 
@@ -187,9 +188,7 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
     historyManager = new HistoryManager(this);
     historyManager.trimHistory();
 
-    showHelpOnFirstLaunch();
-
-    Toast.makeText(this, R.string.msg_default_status, Toast.LENGTH_LONG).show();
+    firstLaunch = showHelpOnFirstLaunch();
   }
 
   @Override
@@ -261,6 +260,10 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
     vibrate = prefs.getBoolean(PreferencesActivity.KEY_VIBRATE, false);
     copyToClipboard = prefs.getBoolean(PreferencesActivity.KEY_COPY_TO_CLIPBOARD, true);
     initBeepSound();
+
+    if (!firstLaunch) {
+      Toast.makeText(this, R.string.msg_default_status, Toast.LENGTH_SHORT).show();      
+    }
   }
 
   private static Vector<BarcodeFormat> parseDecodeFormats(Intent intent) {
@@ -521,8 +524,8 @@ public final class CaptureActivity extends Activity implements SurfaceHolder.Cal
     TextView contentsTextView = (TextView) findViewById(R.id.contents_text_view);
     CharSequence displayContents = resultHandler.getDisplayContents();
     contentsTextView.setText(displayContents);
-    // Crudely scale betweeen 22 and 48 -- bigger font for shorter text
-    int scaledSize = Math.max(22, 48 - displayContents.length() / 4);
+    // Crudely scale betweeen 22 and 42 -- bigger font for shorter text
+    int scaledSize = Math.max(22, 42 - displayContents.length() / 4);
     contentsTextView.setTextSize(TypedValue.COMPLEX_UNIT_SP, scaledSize);
 
     int buttonCount = resultHandler.getButtonCount();

-- 
Multi-format 1D/2D barcode image processing library



More information about the Pkg-google-commits mailing list